==> haskell-yesod-form-1.4.13-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.13
id: yesod-form-1.4.13-4OFhPWFuhsTEtWTKmK3tkj
key: yesod-form-1.4.13-4OFhPWFuhsTEtWTKmK3tkj
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Chinese
abi: 4a5db384edd1f1ab7744bd44f83a6d1b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-form-1.4.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-form-1.4.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/yesod-form-1.4.13
hs-libraries: HSyesod-form-1.4.13-4OFhPWFuhsTEtWTKmK3tkj
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0
    byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq
    email-validate-2.3-HtMdp2gEoJuFuba0i1vSl6
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    persistent-2.6.1-BZtWNugaCvy4iJ6JpB9ZPy
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    shakespeare-2.0.13-7tkYqZznbwm6X0y1el8pnL template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    xss-sanitize-0.3.5.7-JtwY0h7AXl57kDNiQenhrv
    yesod-core-1.4.35.1-Kx8p5Lynpe24mDlJNTuKbn
    yesod-persistent-1.4.2-AkTWJTZYxFwEwoCCDUC8Nm
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.13-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.13
id: yesod-form-1.4.13-8OU4h5Rp1Q3EsbOLJBSi1l
key: yesod-form-1.4.13-8OU4h5Rp1Q3EsbOLJBSi1l
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Chinese
abi: 587de20721f4205d8e2aafa93960b752
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-form-1.4.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/yesod-form-1.4.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/yesod-form-1.4.13
hs-libraries: HSyesod-form-1.4.13-8OU4h5Rp1Q3EsbOLJBSi1l
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0
    byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq
    email-validate-2.3.1-F3mui11fhMXIr19cRxpPee
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    persistent-2.6.1-9ZWX2RZPfKg1JsAfFKOJLS
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    shakespeare-2.0.13-7tkYqZznbwm6X0y1el8pnL template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    xss-sanitize-0.3.5.7-JtwY0h7AXl57kDNiQenhrv
    yesod-core-1.4.35.1-KDHGCjmOZhU9tZs5sLn7si
    yesod-persistent-1.4.2-8Xm3pqQRLYM3IrbHGNQIag
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
